@@ -164,6 +164,9 @@ void MediaObject::seek(qint64 milliseconds)
     const qint64 time = currentTime();
     const qint64 total = totalTime();
 
+    // Reset last tick marker so we emit time even after seeking
+    if (time < m_lastTick)
+        m_lastTick = time;
     if (time < total - m_prefinishMark)
         m_prefinishEmitted = false;
     if (time < total - ABOUT_TO_FINISH_TIME)
@@ -334,7 +337,7 @@ void MediaObject::setSource(const MediaSource &source)
             loadMedia(QLatin1Literal("dvd://") % m_mediaSource.deviceName());
             break;
         case Phonon::Vcd:
-            loadMedia(m_mediaSource.deviceName());
+            loadMedia(QLatin1Literal("vcd://") % m_mediaSource.deviceName());
             break;
 #if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 7, 0))
         case Phonon::BluRay:
